@@ -27,12 +27,10 @@ HTTP = 'http://'
 HTTPS = 'https://'
 
 tso_utilities_streamer_endpoint = setup_data["algorithms"]["streamers"]["utilities"]["url"]
-tso_prepared_streamer_endpoint = setup_data["algorithms"]["streamers"]["prepared"]["url"]
 tso_trades_streamer_endpoint = setup_data["algorithms"]["streamers"]["trades"]["url"]
 
 streams = {
     'utilities': tso_utilities_streamer_endpoint,
-    'prepared': tso_prepared_streamer_endpoint,
     'trades': tso_trades_streamer_endpoint
 }
 
