@@ -2,6 +2,8 @@ from sqlalchemy.ext.declarative import declarative_base
 
 Base = declarative_base()
 
+from .symbol import Symbol
+from .tick import Tick
 # Import all model classes
 from .metadata import Metadata
 from .prediction import Prediction
@@ -29,6 +31,8 @@ __all__ = [
     'Feed',
     'TrainedModel',
     'FeedResult',
+    'Symbol',
+    'Tick'
 ]
 
 
